rename write,read to writeMeta,readMeta

The blobs::DataInterface specifies two methods, write and read which are
meant to be implemented to write or read configuration for the data
interface implementation.

Change-Id: I831a8611596fca50570a4156cbdcfa5c810c0315
Signed-off-by: Patrick Venture <venture@google.com>
diff --git a/lpc_handler.cpp b/lpc_handler.cpp
index 4a584ad..f68a9fa 100644
--- a/lpc_handler.cpp
+++ b/lpc_handler.cpp
@@ -26,7 +26,7 @@
 bool LpcDataHandler::open()
 {
     /* For the ASPEED LPC CTRL driver, the ioctl is required to set up the
      * window, with information from write() below.
      */
     return true;
 }
@@ -59,7 +59,7 @@
     return {};
 }
 
-bool LpcDataHandler::write(const std::vector<std::uint8_t>& configuration)
+bool LpcDataHandler::writeMeta(const std::vector<std::uint8_t>& configuration)
 {
     struct LpcRegion lpcRegion;
 
@@ -86,7 +86,7 @@
     return setInitializedAndReturn(true);
 }
 
-std::vector<std::uint8_t> LpcDataHandler::read()
+std::vector<std::uint8_t> LpcDataHandler::readMeta()
 {
     return {};
 }
@@ -26,7 +26,7 @@
 {
     /* For the ASPEED LPC CTRL driver, the ioctl is required to set up the
-     * window, with information from write() below.
+     * window, with information from writeMeta() below.
      */
     return true;